@@ -887,7 +887,7 @@ class Volatility(models.ImpliedVol):
         
         # Create a sorted list of the different number of strikes
         self.strikes_full = sorted(list(set((self.imp_vol_data[
-            'Strike'].astype(int)))))
+            'Strike'].astype(float)))))
         
         # create copy of implied vol data
         self.imp_vol_data_smoothed = self.imp_vol_data.copy()
@@ -1094,9 +1094,9 @@ class Volatility(models.ImpliedVol):
             
             # Plot the specified voltype against strike
             ax.plot(
-                self.imp_vol_data[self.imp_vol_data['TTM']==tenor]['Strike'], 
-                self.imp_vol_data[self.imp_vol_data['TTM']==tenor][
-                    str(self.vols_dict[str(voltype)])] * 100, 
+                np.array(self.imp_vol_data[self.imp_vol_data['TTM']==tenor]['Strike']), 
+                np.array(self.imp_vol_data[self.imp_vol_data['TTM']==tenor][
+                    str(self.vols_dict[str(voltype)])] * 100), 
                 label=str(exp_date)+' Expiry')
         
         plt.grid(True)
